@@ -33,9 +33,10 @@
 #  define KCONFIGWIDGETS_DEPRECATED_NO_EXPORT KCONFIGWIDGETS_NO_EXPORT KCONFIGWIDGETS_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define KCONFIGWIDGETS_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef KCONFIGWIDGETS_NO_DEPRECATED
+#    define KCONFIGWIDGETS_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
